<meta name="google-site-verification" content="rnnwgvWL65WRkF2NxC8H0l-YSArRZGXA1qfp9e8Ox_8" />

# XIMG-EMBL project

This package is the part of the project on Research and Development of phase-contrast X-ray tomography at the P14 EMBL beamline of PETRA-III (DESY synchrotron). It can do:

- [Flatfield-correction for unstable illumination conditions (i.e. monochromator vibrations)](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/demo_SSIM_1d-PR.ipynb)
- [Parallellized image filtering](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/demo_SSIM_1d-PR.ipynb)
- [Phase retrieval with single distance algorithms (Paganin, Paganin unsharp, Modified Bronnikov, Bronnikov Aided Correction, CTF)](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/demo_SSIM_1d-PR.ipynb)
- [Phase retrieval with multi-distance CTF algorithm](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/Multi_distance_CTF.ipynb)
- [Parallel-beam phase-contrast X-ray tomography](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/CTF_tomo.py)


- [Various functions for image processing](https://github.com/maximka48/XIMG-EMBL/blob/master/maximus48/var.py)
- [Transformation of the image from Cartesian to Polar coordinates](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/Cartesian-2-Polar.ipynb)
- [State of the art (2019) denoising filtering techniques](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/Denoise_filters.ipynb)
- [How to use cross-correlation to find shifts between two images](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/Find_shifts_cross-correlation_properly.ipynb)
- [Auto-focus to find the rotation axis in tomography](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/Auto-focus%20for%20tomo-rotaxis.ipynb)



You may also find useful to check each function or class for a situational description.Feel free to contact me should you have any questions.

Maxim Polikarpov
polikarpov.maxim@mail.ru

https://maximka48.github.io/XIMG-EMBL/

